@@ -1,3 +1,4 @@
 from .data import COINNDataLoader, COINNDataset
 from .nodes import COINNLocal, COINNRemote
-from .coinn_trainer import COINNTrainer
+from .trainer import COINNTrainer
+from .pool import PooledTrainer
